@@ -3,12 +3,12 @@
 Non-Qt processors can be found in `napari/_app_model/injection/_processors.py`.
 """
 
+from collections.abc import Callable
 from concurrent.futures import Future
 from contextlib import nullcontext, suppress
 from functools import partial
 from typing import (
     Any,
-    Callable,
     Optional,
     Union,
     get_origin,
@@ -26,8 +26,8 @@ from napari.layers._source import layer_source
 
 
 def _add_plugin_dock_widget(
-    widget_name_tuple: tuple[Union[FunctionGui, QWidget, Widget], str],
-    viewer: Optional[viewer.Viewer] = None,
+    widget_name_tuple: tuple[FunctionGui | QWidget | Widget, str],
+    viewer: viewer.Viewer | None = None,
 ) -> None:
     if viewer is None:
         viewer = _provide_viewer_or_raise(
@@ -38,10 +38,10 @@ def _add_plugin_dock_widget(
 
 
 def _add_layer_data_tuples_to_viewer(
-    data: Union[tuple, list[tuple]],
-    return_type: Optional[Any] = None,
-    viewer: Optional[viewer.Viewer] = None,
-    source: Optional[dict] = None,
+    data: tuple | list[tuple],
+    return_type: Any | None = None,
+    viewer: viewer.Viewer | None = None,
+    source: dict | None = None,
 ) -> None:
     from napari.utils.misc import ensure_list_of_layer_data_tuple
 
@@ -66,9 +66,9 @@ def _add_layer_data_tuples_to_viewer(
 def _add_layer_data_to_viewer(
     data: Any,
     return_type: Any,
-    viewer: Optional[viewer.Viewer] = None,
-    layer_name: Optional[str] = None,
-    source: Optional[dict] = None,
+    viewer: viewer.Viewer | None = None,
+    layer_name: str | None = None,
+    source: dict | None = None,
 ) -> None:
     """Show a result in the viewer.
 
@@ -117,8 +117,8 @@ def _add_layer_data_to_viewer(
 
 def _add_layer_to_viewer(
     layer: layers.Layer,
-    viewer: Optional[viewer.Viewer] = None,
-    source: Optional[dict] = None,
+    viewer: viewer.Viewer | None = None,
+    source: dict | None = None,
 ) -> None:
     if layer is not None and (viewer := viewer or _provide_viewer()):
         layer._source = layer.source.copy(update=source or {})
@@ -133,8 +133,8 @@ def _add_future_data(
     future: Future,
     return_type: Any,
     _from_tuple: bool = True,
-    viewer: Optional[viewer.Viewer] = None,
-    source: Optional[dict] = None,
+    viewer: viewer.Viewer | None = None,
+    source: dict | None = None,
 ) -> None:
     """Process a Future object.
 
@@ -188,7 +188,7 @@ def _add_future_data(
 
 QPROCESSORS: dict[object, Callable] = {
     Optional[
-        tuple[Union[FunctionGui, QWidget, Widget], str]
+        tuple[FunctionGui | QWidget | Widget, str]
     ]: _add_plugin_dock_widget,
     types.LayerDataTuple: _add_layer_data_tuples_to_viewer,
     list[types.LayerDataTuple]: _add_layer_data_tuples_to_viewer,
