@@ -1,7 +1,6 @@
 import gc
 import os
 import weakref
-from dataclasses import dataclass
 from itertools import product, takewhile
 from unittest import mock
 
@@ -14,6 +13,7 @@ from qtpy.QtCore import QEvent, Qt
 from qtpy.QtGui import QGuiApplication, QKeyEvent
 from qtpy.QtWidgets import QApplication, QMessageBox
 from scipy import ndimage as ndi
+from vispy.app import MouseEvent
 
 from napari._qt.qt_viewer import QtViewer
 from napari._tests.utils import (
@@ -282,7 +282,8 @@ def test_export_figure(make_napari_viewer, tmp_path):
 
     assert viewer.camera.center == camera_center
     assert viewer.camera.zoom == camera_zoom
-    assert img.shape == (250, 250, 4)
+    np.testing.assert_allclose(img.shape, (250, 250, 4), atol=1)
+    # assert img.shape == (250, 250, 4)
     assert np.all(img != np.array([0, 0, 0, 0]))
 
     assert (tmp_path / 'img.png').exists()
@@ -291,11 +292,43 @@ def test_export_figure(make_napari_viewer, tmp_path):
     img = viewer.export_figure(flash=False)
     # allclose accounts for rounding errors when computing size in hidpi aka
     # retina displays
-    np.testing.assert_allclose(img.shape, (250, 499, 4), atol=1)
+    np.testing.assert_allclose(img.shape, (250, 500, 4), atol=1)
 
     layer.scale = [0.12, 0.12]
     img = viewer.export_figure(flash=False)
-    assert img.shape == (250, 250, 4)
+    np.testing.assert_allclose(img.shape, (250, 250, 4), atol=1)
+
+
+def test_export_figure_3d(make_napari_viewer):
+    viewer = make_napari_viewer()
+    np.random.seed(0)
+    # Add image, keep values low to contrast with white background
+    viewer.dims.ndisplay = 3
+    viewer.theme = 'light'
+
+    data = np.random.randint(50, 100, size=(10, 250, 250))
+    layer = viewer.add_image(data)
+
+    # check the non-rotated data (angles = 0,0,90) are exported without any
+    # visible background, since the margins should be 0
+    img = viewer.export_figure()
+    np.testing.assert_allclose(img.shape, (250, 250, 4), atol=1)
+
+    # check that changing the scale still gives the pixel size
+    layer.scale = [1, 0.12, 0.24]
+    img = viewer.export_figure()
+    np.testing.assert_allclose(img.shape, (250, 500, 4), atol=1)
+    layer.scale = [1, 1, 1]
+
+    # rotate the data, export the figure, and check that the rotated figure
+    # shape is greater than the original data shape
+    viewer.camera.angles = (45, 45, 45)
+    img = viewer.export_figure()
+    np.testing.assert_allclose(img.shape, (171, 339, 4), atol=1)
+
+    # The theme is dark, so the canvas will be white. Test that the image
+    # has a white background, roughly more background than the data itself.
+    assert (img[img > 250].shape[0] / img[img <= 200].shape[0]) > 0.5
 
 
 def test_export_rois(make_napari_viewer, tmp_path):
@@ -334,7 +367,15 @@ def test_export_rois(make_napari_viewer, tmp_path):
         (tmp_path / f'roi_{i}.png').exists()
         for i in range(len(roi_shapes_data))
     )
-    assert all(roi.shape == (20, 20, 4) for roi in test_roi)
+
+    # This test uses scaling to adjust the expected size of ROI images
+    # and number of white pixels in the ROI screenshots
+    # The assertion may fail if the test is run on screens with fractional scaling.
+    scaling = viewer.window._qt_window.screen().devicePixelRatio()
+
+    assert all(
+        roi.shape == (20 * scaling, 20 * scaling, 4) for roi in test_roi
+    )
     assert viewer.camera.center == camera_center
     assert viewer.camera.zoom == camera_zoom
 
@@ -347,9 +388,9 @@ def test_export_rois(make_napari_viewer, tmp_path):
     expected_values = [0, 100, 100, 100, 100, 400]
     for index, roi_img in enumerate(test_roi):
         gray_img = roi_img[..., 0]
-        assert np.count_nonzero(gray_img) == expected_values[index], (
-            f'Wrong number of white pixels in the ROI {index}'
-        )
+        assert (
+            np.count_nonzero(gray_img) == expected_values[index] * scaling**2
+        ), f'Wrong number of white pixels in the ROI {index}'
 
     # Not testing the exact content of the screenshot. It seems not to work within the test, but manual testing does.
     viewer.close()
@@ -558,19 +599,14 @@ def test_active_keybindings(make_napari_viewer):
     assert view._key_map_handler.keymap_providers[0] == layer_image
 
 
-@dataclass
-class MouseEvent:
-    # mock mouse event class
-    pos: list[int]
-
-
 def test_process_mouse_event(make_napari_viewer):
     """Test that the correct properties are added to the
     MouseEvent by _process_mouse_events.
     """
     # make a mock mouse event
-    new_pos = [25, 25]
+    new_pos = (25, 25)
     mouse_event = MouseEvent(
+        type='mouse_press',
         pos=new_pos,
     )
     data = np.zeros((5, 20, 20, 20), dtype=int)
@@ -582,7 +618,7 @@ def test_process_mouse_event(make_napari_viewer):
 
     @labels.mouse_drag_callbacks.append
     def on_click(layer, event):
-        np.testing.assert_almost_equal(event.view_direction, [0, 1, 0, 0])
+        np.testing.assert_almost_equal(event.view_direction, [0, -1, 0, 0])
         np.testing.assert_array_equal(event.dims_displayed, [1, 2, 3])
         assert event.dims_point[0] == data.shape[0] // 2
 
@@ -600,8 +636,9 @@ def test_process_mouse_event_2d_layer_3d_viewer(make_napari_viewer):
     """
 
     # make a mock mouse event
-    new_pos = [5, 5]
+    new_pos = (5, 5)
     mouse_event = MouseEvent(
+        type='mouse_press',
         pos=new_pos,
     )
     data = np.zeros((20, 20))
@@ -1194,6 +1231,7 @@ def test_more_than_uint16_colors(qt_viewer):
         for i, (x, y, z) in zip(
             range(256**2 + 20),
             product(np.linspace(0, 1, 256, endpoint=True), repeat=3),
+            strict=False,
         )
     }
     colors[None] = (0, 0, 0, 1)
@@ -1245,7 +1283,7 @@ def test_scale_bar_colored(qt_viewer, qtbot):
     def check_white_scale_bar():
         screenshot = qt_viewer.screenshot(flash=False)
         assert not np.all(screenshot == [0, 0, 0, 255], axis=-1).all()
-        assert np.all(screenshot == [1, 1, 1, 255], axis=-1).any()
+        assert np.all(screenshot == [255, 255, 255, 255], axis=-1).any()
 
     scale_bar.visible = True
     qtbot.waitUntil(check_white_scale_bar)
@@ -1253,8 +1291,8 @@ def test_scale_bar_colored(qt_viewer, qtbot):
     # Check scale bar is colored (canvas has fuchsia `[1, 0, 1, 255]` and not white in it)
     def check_colored_scale_bar():
         screenshot = qt_viewer.screenshot(flash=False)
-        assert not np.all(screenshot == [1, 1, 1, 255], axis=-1).any()
-        assert np.all(screenshot == [1, 0, 1, 255], axis=-1).any()
+        assert not np.all(screenshot == [255, 255, 255, 255], axis=-1).any()
+        assert np.all(screenshot == [255, 0, 255, 255], axis=-1).any()
 
     scale_bar.colored = True
     qtbot.waitUntil(check_colored_scale_bar)
@@ -1262,8 +1300,8 @@ def test_scale_bar_colored(qt_viewer, qtbot):
     # Check scale bar is still visible but not colored (canvas has white again but not fuchsia in it)
     def check_only_white_scale_bar():
         screenshot = qt_viewer.screenshot(flash=False)
-        assert np.all(screenshot == [1, 1, 1, 255], axis=-1).any()
-        assert not np.all(screenshot == [1, 0, 1, 255], axis=-1).any()
+        assert np.all(screenshot == [255, 255, 255, 255], axis=-1).any()
+        assert not np.all(screenshot == [255, 0, 255, 255], axis=-1).any()
 
     scale_bar.colored = False
     qtbot.waitUntil(check_only_white_scale_bar)
@@ -1289,7 +1327,7 @@ def test_scale_bar_ticks(qt_viewer, qtbot):
     def check_white_scale_bar():
         screenshot = qt_viewer.screenshot(flash=False)
         assert not np.all(screenshot == [0, 0, 0, 255], axis=-1).all()
-        assert np.all(screenshot == [1, 1, 1, 255], axis=-1).any()
+        assert np.all(screenshot == [255, 255, 255, 255], axis=-1).any()
 
     scale_bar.visible = True
     qtbot.waitUntil(check_white_scale_bar)
@@ -1301,7 +1339,7 @@ def test_scale_bar_ticks(qt_viewer, qtbot):
     # Check scale bar without ticks (still white present but new screenshot differs from ticks one)
     def check_no_ticks_scale_bar():
         screenshot = qt_viewer.screenshot(flash=False)
-        assert np.all(screenshot == [1, 1, 1, 255], axis=-1).any()
+        assert np.all(screenshot == [255, 255, 255, 255], axis=-1).any()
         npt.assert_raises(
             AssertionError,
             npt.assert_array_equal,
@@ -1315,7 +1353,7 @@ def test_scale_bar_ticks(qt_viewer, qtbot):
     # Check scale bar again has ticks (still white present and new screenshot corresponds with ticks one)
     def check_ticks_scale_bar():
         screenshot = qt_viewer.screenshot(flash=False)
-        assert np.all(screenshot == [1, 1, 1, 255], axis=-1).any()
+        assert np.all(screenshot == [255, 255, 255, 255], axis=-1).any()
         npt.assert_array_equal(screenshot, screenshot_with_ticks)
 
     scale_bar.ticks = True
