@@ -1,13 +1,10 @@
 import inspect
 import warnings
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from functools import partial, wraps
 from types import FunctionType, GeneratorType
 from typing import (
-    Callable,
-    Optional,
     TypeVar,
-    Union,
 )
 
 from superqt.utils import _qthreading
@@ -60,17 +57,15 @@ class GeneratorWorker(
 
 
 def create_worker(
-    func: Union[FunctionType, GeneratorType],
+    func: FunctionType | GeneratorType,
     *args,
-    _start_thread: Optional[bool] = None,
-    _connect: Optional[dict[str, Union[Callable, Sequence[Callable]]]] = None,
-    _progress: Optional[Union[bool, dict[str, Union[int, bool, str]]]] = None,
-    _worker_class: Union[
-        type[GeneratorWorker], type[FunctionWorker], None
-    ] = None,
+    _start_thread: bool | None = None,
+    _connect: dict[str, Callable | Sequence[Callable]] | None = None,
+    _progress: bool | dict[str, int | bool | str] | None = None,
+    _worker_class: type[GeneratorWorker] | type[FunctionWorker] | None = None,
     _ignore_errors: bool = False,
     **kwargs,
-) -> Union[FunctionWorker, GeneratorWorker]:
+) -> FunctionWorker | GeneratorWorker:
     """Convenience function to start a function in another thread.
 
     By default, uses :class:`Worker`, but a custom ``WorkerBase`` subclass may
@@ -195,13 +190,11 @@ def create_worker(
 
 
 def thread_worker(
-    function: Optional[Callable] = None,
-    start_thread: Optional[bool] = None,
-    connect: Optional[dict[str, Union[Callable, Sequence[Callable]]]] = None,
-    progress: Optional[Union[bool, dict[str, Union[int, bool, str]]]] = None,
-    worker_class: Union[
-        type[FunctionWorker], type[GeneratorWorker], None
-    ] = None,
+    function: Callable | None = None,
+    start_thread: bool | None = None,
+    connect: dict[str, Callable | Sequence[Callable]] | None = None,
+    progress: bool | dict[str, int | bool | str] | None = None,
+    worker_class: type[FunctionWorker] | type[GeneratorWorker] | None = None,
     ignore_errors: bool = False,
 ):
     """Decorator that runs a function in a separate thread when called.
