@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional
-
 import numpy as np
 from vispy.color import Colormap as VispyColormap
 from vispy.scene import Node
@@ -22,7 +20,7 @@ from napari.utils.translations import trans
 
 class ImageLayerNode(ScalarFieldLayerNode):
     def __init__(
-        self, custom_node: Node = None, texture_format: Optional[str] = None
+        self, custom_node: Node = None, texture_format: str | None = None
     ) -> None:
         if (
             texture_format == 'auto'
@@ -49,9 +47,7 @@ class ImageLayerNode(ScalarFieldLayerNode):
             texture_format=texture_format,
         )
 
-    def get_node(
-        self, ndisplay: int, dtype: Optional[np.dtype] = None
-    ) -> Node:
+    def get_node(self, ndisplay: int, dtype: np.dtype | None = None) -> Node:
         # Return custom node if we have one.
         if self._custom_node is not None:
             return self._custom_node
