@@ -1,4 +1,4 @@
-from typing import Optional
+import numpy as np
 
 from napari.components._viewer_constants import CursorStyle
 from napari.utils.events import EventedModel
@@ -9,9 +9,9 @@ class Cursor(EventedModel):
 
     Attributes
     ----------
-    position : tuple or None
-        Position of the cursor in world coordinates. None if outside the
-        world.
+    position : tuple of float
+        Position of the cursor in world coordinates. If the cursor is outside of,
+        the canvas, then the last known position is stored instead.
     scaled : bool
         Flag to indicate whether cursor size should be scaled to zoom.
         Only relevant for circle and square cursors which are drawn
@@ -28,14 +28,15 @@ class Cursor(EventedModel):
             * pointing: A finger for pointing
             * standard: The standard cursor
             # crosshair: A crosshair
-    _view_direction : Optional[Tuple[float, float, float]]
-        The vector describing the direction of the camera in the scene.
+    _view_direction : Optional[np.ndarray]
+        The vector describing the direction of the camera in the scene
+        in world coordinates.
         This is None when viewing in 2D.
     """
 
     # fields
-    position: tuple[float, ...] = (1, 1)
+    position: tuple[float, ...] = (1.0, 1.0)
     scaled: bool = True
     size = 1.0
     style: CursorStyle = CursorStyle.STANDARD
-    _view_direction: Optional[tuple[float, float, float]] = None
+    _view_direction: np.ndarray | None = None
