@@ -1,5 +1,6 @@
+from collections.abc import Callable
 from dataclasses import dataclass, field
-from typing import Any, Callable, Optional, Union
+from typing import TYPE_CHECKING, Any
 
 import numpy as np
 
@@ -9,9 +10,13 @@ from napari.layers.image._image_utils import project_slice
 from napari.layers.utils._slice_input import _SliceInput, _ThickNDSlice
 from napari.types import ArrayLike
 from napari.utils._dask_utils import DaskIndexer
+from napari.utils._dtype import normalize_dtype
 from napari.utils.misc import reorder_after_dim_reduction
 from napari.utils.transforms import Affine
 
+if TYPE_CHECKING:
+    from numpy.typing import DTypeLike
+
 
 @dataclass(frozen=True)
 class _ImageView:
@@ -87,7 +92,8 @@ class _ImageSliceResponse:
         *,
         slice_input: _SliceInput,
         rgb: bool,
-        request_id: Optional[int] = None,
+        request_id: int | None = None,
+        dtype: 'DTypeLike' = np.uint8,
     ) -> '_ImageSliceResponse':
         """Returns an empty image slice response.
 
@@ -108,11 +114,13 @@ class _ImageSliceResponse:
             If None, a new request id will be returned, which guarantees that
             the empty slice never appears as loaded. (Used for layer
             initialisation before attempting data loading.)
+        dtype : np.dtype
+            The dtype of the empty image slice.
         """
         shape = (1,) * slice_input.ndisplay
         if rgb:
             shape = shape + (3,)
-        data = np.zeros(shape, dtype=np.uint8)
+        data = np.zeros(shape, dtype=normalize_dtype(dtype))
         image = _ImageView.from_view(data)
         ndim = slice_input.ndim
         tile_to_data = Affine(
@@ -158,6 +166,7 @@ class _ImageSliceResponse:
             tile_to_data=self.tile_to_data,
             slice_input=self.slice_input,
             request_id=self.request_id,
+            empty=self.empty,
         )
 
 
@@ -203,7 +212,10 @@ class _ImageSliceRequest:
     def __call__(self) -> _ImageSliceResponse:
         if self._slice_out_of_bounds():
             return _ImageSliceResponse.make_empty(
-                slice_input=self.slice_input, rgb=self.rgb, request_id=self.id
+                slice_input=self.slice_input,
+                rgb=self.rgb,
+                request_id=self.id,
+                dtype=self.data.dtype,
             )
         with self.dask_indexer():
             return (
@@ -355,7 +367,7 @@ class _ImageSliceRequest:
     @staticmethod
     def _point_to_slices(
         point: tuple[float, ...],
-    ) -> tuple[Union[slice, int], ...]:
+    ) -> tuple[slice | int, ...]:
         # no need to check out of bounds here cause it's guaranteed
 
         # values in point and margins are np.nan if no slicing should happen along that dimension
