@@ -1,13 +1,27 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+import itertools
+import tempfile
+import typing
+from typing import TYPE_CHECKING, overload
 
 import numpy as np
+from skimage import measure
 from skimage.draw import line, polygon2mask
-from vispy.geometry import PolygonData
+from vispy.geometry import Triangulation
 from vispy.visuals.tube import _frenet_frames
 
-from napari.layers.utils.layer_utils import segment_normal
+from napari.layers.shapes import (
+    _accelerated_triangulate_dispatch as _triangulate_dispatch,
+    _accelerated_triangulate_python as _triangulate_py,
+)
+from napari.layers.shapes.shape_types import (
+    CoordinateArray,
+    CoordinateArray2D,
+    CoordinateArray3D,
+    EdgeArray,
+    TriangleArray,
+)
 from napari.utils.translations import trans
 
 if TYPE_CHECKING:
@@ -20,38 +34,41 @@ except ModuleNotFoundError:
     triangulate = None
 
 
-try:
-    from napari.layers.shapes._accelerated_triangulate import (
-        create_box_from_bounding as acc_create_box_from_bounding,
-        generate_2D_edge_meshes as acc_generate_2D_edge_meshes,
-    )
-except ImportError:
-    acc_generate_2D_edge_meshes = None
-    acc_create_box_from_bounding = None
+def find_planar_axis(
+    points: npt.NDArray,
+) -> tuple[npt.NDArray, int | None, float | None]:
+    """Find an axis along which the input points are planar.
 
+    If points are 2D, they are returned unchanged.
 
-def _is_convex(poly: npt.NDArray) -> bool:
-    """Check whether a polygon is convex.
+    If there is a planar axis, return the corresponding 2D points, the axis
+    position, and the coordinate of the plane.
+
+    If there is *no* planar axis, return an empty dataset.
 
     Parameters
     ----------
-    poly: numpy array of floats, shape (N, 3)
-        Polygon vertices, in order.
+    points : array, shape (npoints, ndim)
+        An array of point coordinates. ``ndim`` must be 2 or 3.
 
     Returns
     -------
-    bool
-        True if the given polygon is convex.
+    points2d : array, shape (npoints | 0, 2)
+        Array of 2D points. May be empty if input points are not planar along
+        any axis.
+    axis_idx : int | None
+        The axis along which points are planar.
+    value : float | None
+        The coordinate of the points along ``axis``.
     """
-    fst = poly[:-2]
-    snd = poly[1:-1]
-    thrd = poly[2:]
-    orn_set = np.unique(orientation(fst.T, snd.T, thrd.T))
-    if orn_set.size != 1:
-        return False
-    return (orn_set[0] == orientation(poly[-2], poly[-1], poly[0])) and (
-        orn_set[0] == orientation(poly[-1], poly[0], poly[1])
-    )
+    ndim = points.shape[1]
+    if ndim == 2:
+        return points, None, None
+    for axis_idx in range(ndim):
+        values = np.unique(points[:, axis_idx])
+        if len(values) == 1:
+            return np.delete(points, axis_idx, axis=1), axis_idx, values[0]
+    return np.empty((0, 2), dtype=points.dtype), None, None
 
 
 def _fan_triangulation(poly: npt.NDArray) -> tuple[npt.NDArray, npt.NDArray]:
@@ -222,10 +239,10 @@ def lines_intersect(p1, q1, p2, q2):
         Bool indicating if line segment p1q1 intersects line segment p2q2
     """
     # Determine four orientations
-    o1 = orientation(p1, q1, p2)
-    o2 = orientation(p1, q1, q2)
-    o3 = orientation(p2, q2, p1)
-    o4 = orientation(p2, q2, q1)
+    o1 = _triangulate_py.orientation(p1, q1, p2)
+    o2 = _triangulate_py.orientation(p1, q1, q2)
+    o3 = _triangulate_py.orientation(p2, q2, p1)
+    o4 = _triangulate_py.orientation(p2, q2, q1)
 
     # Test general case
     if (o1 != o2) and (o3 != o4):
@@ -269,12 +286,9 @@ def on_segment(p, q, r):
     on : bool
         Bool indicating if q is on segment from p to r
     """
-    if (
-        q[0] <= max(p[0], r[0])
-        and q[0] >= min(p[0], r[0])
-        and q[1] <= max(p[1], r[1])
-        and q[1] >= min(p[1], r[1])
-    ):
+    if max(p[0], r[0]) >= q[0] >= min(p[0], r[0]) and max(p[1], r[1]) >= q[
+        1
+    ] >= min(p[1], r[1]):
         on = True
     else:
         on = False
@@ -282,30 +296,6 @@ def on_segment(p, q, r):
     return on
 
 
-def orientation(p, q, r):
-    """Determines oritentation of ordered triplet (p, q, r)
-
-    Parameters
-    ----------
-    p : (2,) array
-        Array of first point of triplet
-    q : (2,) array
-        Array of second point of triplet
-    r : (2,) array
-        Array of third point of triplet
-
-    Returns
-    -------
-    val : int
-        One of (-1, 0, 1). 0 if p, q, r are collinear, 1 if clockwise, and -1
-        if counterclockwise.
-    """
-    val = (q[1] - p[1]) * (r[0] - q[0]) - (q[0] - p[0]) * (r[1] - q[1])
-    val = np.sign(val)
-
-    return val
-
-
 def is_collinear(points: npt.NDArray) -> bool:
     """Determines if a list of 2D points are collinear.
 
@@ -324,7 +314,10 @@ def is_collinear(points: npt.NDArray) -> bool:
 
     # The collinearity test takes three points, the first two are the first
     # two in the list, and then the third is iterated through in the loop
-    return all(orientation(points[0], points[1], p) == 0 for p in points[2:])
+    return all(
+        _triangulate_py.orientation(points[0], points[1], p) == 0
+        for p in points[2:]
+    )
 
 
 def point_to_lines(point, lines):
@@ -387,41 +380,6 @@ def point_to_lines(point, lines):
     return index, location
 
 
-def create_box_from_bounding(bounding_box: npt.NDArray) -> npt.NDArray:
-    """Creates the axis aligned interaction box of a bounding box
-
-    Parameters
-    ----------
-    bounding_box : np.ndarray
-        2x2 array of the bounding box. The first row is the minimum values and
-        the second row is the maximum values
-
-    Returns
-    -------
-    box : np.ndarray
-        9x2 array of vertices of the interaction box. The first 8 points are
-        the corners and midpoints of the box in clockwise order starting in the
-        upper-left corner. The last point is the center of the box
-    """
-    tl = bounding_box[(0, 0), (0, 1)]
-    br = bounding_box[(1, 1), (0, 1)]
-    tr = bounding_box[(1, 0), (0, 1)]
-    bl = bounding_box[(0, 1), (0, 1)]
-    return np.array(
-        [
-            tl,
-            (tl + tr) / 2,
-            tr,
-            (tr + br) / 2,
-            br,
-            (br + bl) / 2,
-            bl,
-            (bl + tl) / 2,
-            (tl + br) / 2,
-        ]
-    )
-
-
 def create_box(data: npt.NDArray) -> npt.NDArray:
     """Creates the axis aligned interaction box of a list of points
 
@@ -476,7 +434,7 @@ def rectangle_to_box(data: npt.NDArray) -> npt.NDArray:
         the corners and midpoints of the box in clockwise order starting in the
         upper-left corner. The last point is the center of the box
     """
-    if not data.shape[0] == 4:
+    if data.shape[0] != 4:
         raise ValueError(
             trans._(
                 'Data shape does not match expected `[4, D]` shape specifying corners for the rectangle',
@@ -586,7 +544,7 @@ def triangulate_ellipse(
 
 
     """
-    if not corners.shape[0] == 4:
+    if corners.shape[0] != 4:
         raise ValueError(
             trans._(
                 'Data shape does not match expected `[4, D]` shape specifying corners for the ellipse',
@@ -632,12 +590,188 @@ def triangulate_ellipse(
     return vertices, triangles
 
 
-def triangulate_face(data: npt.NDArray) -> tuple[npt.NDArray, npt.NDArray]:
+def _cull_triangles_not_in_poly(vertices, triangles, poly):
+    """Remove triangles that are not inside the polygon.
+
+    Unlike VisPy, triangle's constrained Delaunay triangulation
+    returns triangles inside the hole as well. (I guess in case you want
+    to render holes but in a different color, for example.) In our case,
+    we want to get rid of them, so we cull them with some NumPy
+    calculations.
+
+    Parameters
+    ----------
+    vertices: np.ndarray[np.floating], shape (N, 2)
+        The vertices of the triangulation.
+    triangles: np.ndarray[np.intp], shape (M, 3)
+        Triangles in the triangulation, defined by three indices into the
+        vertex array.
+    poly: np.ndarray[np.floating], shape (P, 2)
+        The vertices of the polygon, in order. Holes in the polygon are
+        defined by an embedded polygon that starts from an arbitrary point in
+        the enclosing polygon and wind in the opposite direction.
+
+    Returns
+    -------
+    culled_triangles: np.ndarray[np.intp], shape (P, 3), P ≤ M
+        A subset of the input triangles.
+    """
+    centers = np.mean(vertices[triangles], axis=1)
+    in_poly = measure.points_in_poly(centers, poly)
+    return triangles[in_poly]
+
+
+def _fix_vertices_if_needed(
+    vertices: CoordinateArray2D, axis: int | None, value: float | None
+) -> CoordinateArray:
+    """Ensure vertices are planar along a given axis.
+
+    If an axis and value are provided, this function inserts the value as
+    a new coordinate along the given axis.
+    Used to convert 2D vertices in 3D vertices along the plane.
+
+    Parameters
+    ----------
+    vertices: np.ndarray[np.floating], shape (N, 2)
+        The vertices of the triangulation.
+    axis: int
+        The axis along which the vertices are planar.
+    value: float
+        The coordinate of the plane.
+
+    Returns
+    -------
+    new_vertices: np.ndarray[np.floating], shape (N, 3)
+        The vertices of the triangulation with the given axis fixed.
+    """
+    if axis is None or value is None:
+        return vertices
+    new_vertices = np.insert(vertices, axis, value, axis=1)
+    return new_vertices
+
+
+def triangulate_face_and_edges(
+    polygon_vertices: CoordinateArray,
+    triangulate_face_: typing.Callable,
+) -> tuple[
+    tuple[np.ndarray, np.ndarray], tuple[np.ndarray, np.ndarray, np.ndarray]
+]:
+    """Determines the triangulation of the face and edges of a shape.
+
+    Parameters
+    ----------
+    polygon_vertices : np.ndarray
+        Nx2 array of vertices of shape to be triangulated
+
+    Returns
+    -------
+    face_tri : tuple[np.ndarray, np.ndarray]
+        Tuple of vertices and triangles of the face.
+    edge_tri : tuple[np.ndarray, np.ndarray, np.ndarray]
+        Tuple of vertices, offsets, and triangles of the edges.
+    """
+    data2d, axis, value = find_planar_axis(polygon_vertices)
+
+    if not len(data2d) or is_collinear(data2d):
+        face_tri = (
+            np.empty((0, polygon_vertices.shape[1]), dtype=np.float32),
+            np.empty((0, 3), dtype=np.int32),
+        )
+        edge_tri = triangulate_edge(polygon_vertices, closed=True)
+        return face_tri, edge_tri
+
+    if _triangulate_dispatch.is_convex(data2d):
+        vertices, triangles = _fan_triangulation(data2d)
+        face_tri = (
+            _fix_vertices_if_needed(vertices, axis=axis, value=value),
+            triangles,
+        )
+        edge_tri = triangulate_edge(polygon_vertices, closed=True)
+        return face_tri, edge_tri
+
+    raw_vertices, edges = _triangulate_dispatch.normalize_vertices_and_edges(
+        data2d, close=True
+    )
+
+    vertices, triangles = triangulate_face_(
+        raw_vertices.copy(), edges.copy(), polygon_vertices
+    )
+
+    face_tri = (
+        _fix_vertices_if_needed(vertices, axis=axis, value=value),
+        triangles,
+    )
+
+    if len(edges) == len(polygon_vertices):
+        # There is no removed edge
+        edge_tri = triangulate_edge(polygon_vertices, closed=True)
+    else:
+        # There is at least one removed edge
+        edge_tri = reconstruct_and_triangulate_edge(raw_vertices, edges)
+
+    return face_tri, edge_tri
+
+
+@overload
+def reconstruct_and_triangulate_edge(
+    vertices: CoordinateArray2D, edges: EdgeArray
+) -> tuple[CoordinateArray2D, CoordinateArray2D, TriangleArray]: ...
+
+
+@overload
+def reconstruct_and_triangulate_edge(
+    vertices: CoordinateArray3D, edges: EdgeArray
+) -> tuple[CoordinateArray3D, CoordinateArray3D, TriangleArray]: ...
+
+
+def reconstruct_and_triangulate_edge(
+    vertices: CoordinateArray, edges: EdgeArray
+) -> tuple[CoordinateArray, CoordinateArray, TriangleArray]:
+    """Triangulate edges when vertices form multiple disjoint polygons.
+
+    Parameters
+    ----------
+    vertices: np.ndarray
+        Nx2 or Nx3 array of vertices of shape to be triangulated.
+        Cannot contain duplicated vertices.
+    edges: np.ndarray
+        list of edges encoded as vertices indices.
+        Cannot contain duplicated vertices.
+
+    Returns
+    -------
+    edges_tri: tuple[ndarray, ndarray, ndarray]
+        vertices, offsets, and triangles of the edge triangulation(s).
+    """
+    polygon_list = _triangulate_dispatch.reconstruct_polygons_from_edges(
+        vertices, edges
+    )
+    centers_list = []
+    offset_list = []
+    triangles_list = []
+    offset_idx = 0
+    for polygon in polygon_list:
+        centers, offset, triangles = triangulate_edge(polygon, closed=True)
+        centers_list.append(centers)
+        offset_list.append(offset)
+        triangles_list.append(triangles + offset_idx)
+        offset_idx += len(centers)
+    return (
+        np.concatenate(centers_list),
+        np.concatenate(offset_list),
+        np.concatenate(triangles_list),
+    )
+
+
+def triangulate_face(
+    polygon_vertices: CoordinateArray2D,
+    triangulate_face_: typing.Callable,
+) -> tuple[CoordinateArray2D, TriangleArray]:
     """Determines the triangulation of the face of a shape.
 
     Parameters
     ----------
-    data : np.ndarray
+    polygon_vertices : np.ndarray
         Nx2 array of vertices of shape to be triangulated
 
     Returns
@@ -648,37 +782,112 @@ def triangulate_face(data: npt.NDArray) -> tuple[npt.NDArray, npt.NDArray]:
         Px3 array of the indices of the vertices that will form the
         triangles of the triangulation
     """
+    if _triangulate_dispatch.is_convex(polygon_vertices):
+        return _fan_triangulation(polygon_vertices)
 
-    if triangulate is not None:
-        len_data = len(data)
+    raw_vertices, edges = _triangulate_dispatch.normalize_vertices_and_edges(
+        polygon_vertices, close=True
+    )
+    return triangulate_face_(raw_vertices, edges, polygon_vertices)
 
-        edges = np.empty((len_data, 2), dtype=np.uint32)
-        edges[:, 0] = np.arange(len_data)
-        edges[:, 1] = np.arange(1, len_data + 1)
-        # connect last with first vertex
-        edges[-1, 1] = 0
 
-        res = triangulate({'vertices': data, 'segments': edges}, 'p')
-        vertices, triangles = res['vertices'], res['triangles']
-    elif _is_convex(data):
-        vertices, triangles = _fan_triangulation(data)
-    else:
-        vertices, triangles = PolygonData(vertices=data).triangulate()
+@overload
+def triangulate_face_vispy(
+    raw_vertices: CoordinateArray2D,
+    edges: EdgeArray,
+    polygon_vertices: CoordinateArray,
+) -> tuple[CoordinateArray2D, TriangleArray]: ...
+
+
+@overload
+def triangulate_face_vispy(
+    raw_vertices: CoordinateArray3D,
+    edges: EdgeArray,
+    polygon_vertices: CoordinateArray,
+) -> tuple[CoordinateArray3D, TriangleArray]: ...
+
+
+def triangulate_face_vispy(
+    raw_vertices: CoordinateArray,
+    edges: EdgeArray,
+    polygon_vertices: CoordinateArray,
+) -> tuple[CoordinateArray, TriangleArray]:
+    try:
+        tri = Triangulation(raw_vertices, edges)
+        tri.triangulate()
+        vertices, triangles = tri.pts, tri.tris
+    except Exception as e:  # pragma: no cover
+        path, text_path = _save_failed_triangulation(
+            raw_vertices, backend='vispy'
+        )
+        raise RuntimeError(
+            f'Triangulation failed. Data saved to {path} and {text_path}'
+        ) from e
 
     triangles = triangles.astype(np.uint32)
 
     return vertices, triangles
 
 
+@overload
+def triangulate_face_triangle(
+    raw_vertices: CoordinateArray2D,
+    edges: EdgeArray,
+    polygon_vertices: CoordinateArray,
+) -> tuple[CoordinateArray2D, TriangleArray]: ...
+
+
+@overload
+def triangulate_face_triangle(
+    raw_vertices: CoordinateArray3D,
+    edges: EdgeArray,
+    polygon_vertices: CoordinateArray,
+) -> tuple[CoordinateArray3D, TriangleArray]: ...
+
+
+def triangulate_face_triangle(
+    raw_vertices: CoordinateArray,
+    edges: EdgeArray,
+    polygon_vertices: CoordinateArray,
+) -> tuple[CoordinateArray, TriangleArray]:
+    res = triangulate({'vertices': raw_vertices, 'segments': edges}, opts='p')
+    vertices = res['vertices']
+    raw_triangles = res['triangles']
+    # triangle's constrained Delaunay triangulation
+    # returns triangles inside the hole. (perhaps in case you want
+    # to render holes but in a different color, for example.) In our case,
+    # we want to get rid of them, so we cull them with some NumPy
+    # calculations
+    triangles = _cull_triangles_not_in_poly(
+        vertices, raw_triangles, polygon_vertices
+    )
+    triangles = triangles.astype(np.uint32)
+
+    return vertices, triangles
+
+
+@typing.overload
 def triangulate_edge(
-    path: npt.NDArray, closed: bool = False
-) -> tuple[npt.NDArray, npt.NDArray, npt.NDArray]:
-    """Determines the triangulation of a path. The resulting `offsets` can
-    multiplied by a `width` scalar and be added to the resulting `centers`
-    to generate the vertices of the triangles for the triangulation, i.e.
-    `vertices = centers + width*offsets`. Using the `centers` and `offsets`
-    representation thus allows for the computed triangulation to be
-    independent of the line width.
+    path: CoordinateArray2D, closed: bool = False
+) -> tuple[CoordinateArray2D, CoordinateArray2D, TriangleArray]: ...
+
+
+@typing.overload
+def triangulate_edge(
+    path: CoordinateArray3D, closed: bool = False
+) -> tuple[CoordinateArray3D, CoordinateArray3D, TriangleArray]: ...
+
+
+def triangulate_edge(
+    path: CoordinateArray, closed: bool = False
+) -> tuple[CoordinateArray, CoordinateArray, TriangleArray]:
+    """Determines the triangulation of a path.
+
+    The resulting `offsets` can multiplied by a `width` scalar and be added
+    to the resulting `centers` to generate the vertices of the triangles for
+    the triangulation, i.e. `vertices = centers + width*offsets`. Using the
+    `centers` and `offsets` representation thus allows for the computed
+    triangulation to be independent of the line width.
 
     Parameters
     ----------
@@ -713,8 +922,10 @@ def triangulate_edge(
         clean_path = path
 
     if clean_path.shape[-1] == 2:
-        centers, offsets, triangles = _generate_2D_edge_meshes(
-            np.asarray(clean_path, dtype=np.float32), closed=closed
+        centers, offsets, triangles = (
+            _triangulate_dispatch.generate_2D_edge_meshes(
+                np.asarray(clean_path, dtype=np.float32), closed=closed
+            )
         )
     else:
         centers, offsets, triangles = generate_tube_meshes(
@@ -725,179 +936,6 @@ def triangulate_edge(
     return centers, offsets, triangles
 
 
-def _mirror_point(x, y):
-    return 2 * y - x
-
-
-def _sign_nonzero(x):
-    y = np.sign(x).astype(int)
-    y[y == 0] = 1
-    return y
-
-
-def _sign_cross(x, y):
-    """sign of cross product (faster for 2d)"""
-    if x.shape[1] == y.shape[1] == 2:
-        return _sign_nonzero(x[:, 0] * y[:, 1] - x[:, 1] * y[:, 0])
-    if x.shape[1] == y.shape[1] == 3:
-        return _sign_nonzero(np.cross(x, y))
-
-    raise ValueError(x.shape[1], y.shape[1])
-
-
-def generate_2D_edge_meshes(path, closed=False, limit=3, bevel=False):
-    """Determines the triangulation of a path in 2D. The resulting `offsets`
-    can be multiplied by a `width` scalar and be added to the resulting
-    `centers` to generate the vertices of the triangles for the triangulation,
-    i.e. `vertices = centers + width*offsets`. Using the `centers` and
-    `offsets` representation thus allows for the computed triangulation to be
-    independent of the line width.
-
-    Parameters
-    ----------
-    path : np.ndarray
-        Nx2 or Nx3 array of central coordinates of path to be triangulated
-    closed : bool
-        Bool which determines if the path is closed or not
-    limit : float
-        Miter limit which determines when to switch from a miter join to a
-        bevel join
-    bevel : bool
-        Bool which if True causes a bevel join to always be used. If False
-        a bevel join will only be used when the miter limit is exceeded
-
-    Returns
-    -------
-    centers : np.ndarray
-        Mx2 or Mx3 array central coordinates of path triangles.
-    offsets : np.ndarray
-        Mx2 or Mx3 array of the offsets to the central coordinates that need to
-        be scaled by the line width and then added to the centers to
-        generate the actual vertices of the triangulation
-    triangles : np.ndarray
-        Px3 array of the indices of the vertices that will form the
-        triangles of the triangulation
-    """
-
-    path = np.asarray(path, dtype=float)
-
-    # add first vertex to the end if closed
-    if closed:
-        path = np.concatenate((path, [path[0]]))
-
-    # extend path by adding a vertex at beginning and end
-    # to get the mean normals correct
-    if closed:
-        _ext_point1 = path[-2]
-        _ext_point2 = path[1]
-    else:
-        _ext_point1 = _mirror_point(path[1], path[0])
-        _ext_point2 = _mirror_point(path[-2], path[-1])
-
-    full_path = np.concatenate(([_ext_point1], path, [_ext_point2]), axis=0)
-
-    # full_normals[:-1], full_normals[1:] are normals left and right of each path vertex
-    full_normals = segment_normal(full_path[:-1], full_path[1:])
-
-    # miters per vertex are the average of left and right normals
-    miters = 0.5 * (full_normals[:-1] + full_normals[1:])
-
-    # scale miters such that their dot product with normals is 1
-    _mf_dot = np.expand_dims(
-        np.einsum('ij,ij->i', miters, full_normals[:-1]), -1
-    )
-
-    miters = np.divide(
-        miters,
-        _mf_dot,
-        where=np.abs(_mf_dot) > 1e-10,
-    )
-
-    miter_lengths_squared = (miters**2).sum(axis=1)
-
-    # miter_signs -> +1 if edges turn clockwise, -1 if anticlockwise
-    # used later to discern bevel positions
-    miter_signs = _sign_cross(full_normals[1:], full_normals[:-1])
-    miters = 0.5 * miters
-
-    # generate centers/offsets
-    centers = np.repeat(path, 2, axis=0)
-    offsets = np.repeat(miters, 2, axis=0)
-    offsets[::2] *= -1
-
-    triangles0 = np.tile(np.array([[0, 1, 3], [0, 3, 2]]), (len(path) - 1, 1))
-    triangles = triangles0 + 2 * np.repeat(
-        np.arange(len(path) - 1)[:, np.newaxis], 2, 0
-    )
-
-    # get vertex indices that are to be beveled
-    idx_bevel = np.where(
-        np.bitwise_or(bevel, miter_lengths_squared > (limit**2))
-    )[0]
-
-    if len(idx_bevel) > 0:
-        idx_offset = (miter_signs[idx_bevel] < 0).astype(int)
-
-        # outside and inside offsets are treated differently (only outside offsets get beveled)
-        # See drawing at:
-        # https://github.com/napari/napari/pull/6706#discussion_r1528790407
-        idx_bevel_outside = 2 * idx_bevel + idx_offset
-        idx_bevel_inside = 2 * idx_bevel + (1 - idx_offset)
-        sign_bevel = np.expand_dims(miter_signs[idx_bevel], -1)
-
-        # adjust offset of outer offset
-        offsets[idx_bevel_outside] = (
-            -0.5 * full_normals[:-1][idx_bevel] * sign_bevel
-        )
-        # adjust/normalize length of inner offset
-        offsets[idx_bevel_inside] /= np.sqrt(
-            miter_lengths_squared[idx_bevel, np.newaxis]
-        )
-
-        # special cases for the last vertex
-        _nonspecial = idx_bevel != len(path) - 1
-
-        idx_bevel = idx_bevel[_nonspecial]
-        idx_bevel_outside = idx_bevel_outside[_nonspecial]
-        sign_bevel = sign_bevel[_nonspecial]
-        idx_offset = idx_offset[_nonspecial]
-
-        # create new "right" bevel vertices to be added later
-        centers_bevel = path[idx_bevel]
-        offsets_bevel = -0.5 * full_normals[1:][idx_bevel] * sign_bevel
-
-        n_centers = len(centers)
-        # change vertices of triangles to the newly added right vertices
-        triangles[2 * idx_bevel, idx_offset] = len(centers) + np.arange(
-            len(idx_bevel)
-        )
-        triangles[2 * idx_bevel + (1 - idx_offset), idx_offset] = (
-            n_centers + np.arange(len(idx_bevel))
-        )
-
-        # add a new center/bevel triangle
-        triangles0 = np.tile(np.array([[0, 1, 2]]), (len(idx_bevel), 1))
-        triangles_bevel = np.array(
-            [
-                2 * idx_bevel + idx_offset,
-                2 * idx_bevel + (1 - idx_offset),
-                n_centers + np.arange(len(idx_bevel)),
-            ]
-        ).T
-        # add all new centers, offsets, and triangles
-        centers = np.concatenate([centers, centers_bevel])
-        offsets = np.concatenate([offsets, offsets_bevel])
-        triangles = np.concatenate([triangles, triangles_bevel])
-
-    # extracting vectors (~4x faster than np.moveaxis)
-    a, b, c = tuple((centers + offsets)[triangles][:, i] for i in range(3))
-    # flip negative oriented triangles
-    flip_idx = _sign_cross(b - a, c - a) < 0
-    triangles[flip_idx] = np.flip(triangles[flip_idx], axis=-1)
-
-    return centers, offsets, triangles
-
-
 def generate_tube_meshes(path, closed=False, tube_points=10):
     """Generates list of mesh vertices and triangles from a path
 
@@ -928,7 +966,7 @@ def generate_tube_meshes(path, closed=False, tube_points=10):
     if closed and not np.array_equal(points[0], points[-1]):
         points = np.concatenate([points, [points[0]]], axis=0)
 
-    tangents, normals, binormals = _frenet_frames(points, closed)
+    _tangents, normals, binormals = _frenet_frames(points, closed)
 
     segments = len(points) - 1
 
@@ -948,19 +986,19 @@ def generate_tube_meshes(path, closed=False, tube_points=10):
         grid_off[i] = cx[:, np.newaxis] * normal + cy[:, np.newaxis] * binormal
 
     # construct the mesh
-    indices = []
-    for i in range(segments):
-        for j in range(tube_points):
-            ip = (i + 1) % segments if closed else i + 1
-            jp = (j + 1) % tube_points
+    indices: list[tuple[int, int, int]] = []
+    for i, j in itertools.product(range(segments), range(tube_points)):
+        ip = (i + 1) % segments if closed else i + 1
+        jp = (j + 1) % tube_points
 
-            index_a = i * tube_points + j
-            index_b = ip * tube_points + j
-            index_c = ip * tube_points + jp
-            index_d = i * tube_points + jp
+        index_a = i * tube_points + j
+        index_b = ip * tube_points + j
+        index_c = ip * tube_points + jp
+        index_d = i * tube_points + jp
 
-            indices.append([index_a, index_b, index_d])
-            indices.append([index_b, index_c, index_d])
+        indices.extend(
+            ([index_a, index_b, index_d], [index_b, index_c, index_d])  # type: ignore[arg-type]
+        )
     triangles = np.array(indices, dtype=np.uint32)
 
     centers = grid.reshape(grid.shape[0] * grid.shape[1], 3)
@@ -999,7 +1037,7 @@ def path_to_mask(
     vertices = vertices[~duplicates]
 
     iis, jjs = [], []
-    for v1, v2 in zip(vertices, vertices[1:]):
+    for v1, v2 in itertools.pairwise(vertices):
         ii, jj = line(*v1, *v2)
         iis.extend(ii.tolist())
         jjs.extend(jj.tolist())
@@ -1338,11 +1376,49 @@ def rdp(vertices: npt.NDArray, epsilon: float) -> npt.NDArray:
     return vertices
 
 
-if acc_generate_2D_edge_meshes is not None:
-    _generate_2D_edge_meshes = acc_generate_2D_edge_meshes
-else:  # pragma: no cover
-    _generate_2D_edge_meshes = generate_2D_edge_meshes
+def _save_failed_triangulation(
+    data: np.ndarray, target_dir: str | None = None, backend: str = ''
+) -> tuple[str, str]:
+    """Save data to temporary files for debugging.
 
+    This function saves input data when triangulation fails.
+    It saves the same data to both a .npz file and a .txt file within the
+    temporary directory, and returns the paths to the saved files.
 
-if acc_create_box_from_bounding is not None:
-    create_box_from_bounding = acc_create_box_from_bounding
+    Parameters
+    ----------
+    data : np.ndarray
+        The data to save.
+    target_dir: str or None
+        Path to the directory where the files will be saved.
+        If None, the default
+    backend: str, options
+        The backend used for triangulation. This is used to generate the
+        filename prefix.
+
+    Returns
+    -------
+    tuple[str, str]
+        The paths to the saved files.
+
+    Notes
+    -----
+    Use TMPDIR environment variable to set the temporary directory.
+    """
+    with tempfile.NamedTemporaryFile(
+        delete=False,
+        suffix='.npz',
+        prefix=f'napari_{backend}_triang_',
+        dir=target_dir,
+    ) as binary_file:
+        np.savez(binary_file, data=data)
+    with tempfile.NamedTemporaryFile(
+        delete=False,
+        suffix='.txt',
+        prefix=f'napari_{backend}_triang_',
+        mode='w',
+        dir=target_dir,
+    ) as text_file:
+        np.savetxt(text_file, data)
+
+    return binary_file.name, text_file.name
