@@ -3,7 +3,7 @@ from collections import OrderedDict, defaultdict
 from collections.abc import Iterable
 from functools import lru_cache
 from threading import Lock
-from typing import NamedTuple, Optional, Union
+from typing import NamedTuple, Union
 
 import numpy as np
 import skimage.color as colorconv
@@ -339,7 +339,9 @@ def color_dict_to_colormap(colors):
 
     control2index = {
         tuple(color): control_point
-        for color, control_point in zip(colormap.colors, colormap.controls)
+        for color, control_point in zip(
+            colormap.colors, colormap.controls, strict=False
+        )
     }
 
     control_small_delta = 0.5 / len(control_colors)
@@ -824,7 +826,7 @@ def ensure_colormap(colormap: ValidColormapArg) -> Colormap:
             if (
                 len(colormap) == 2
                 and isinstance(colormap[0], str)
-                and isinstance(colormap[1], (VispyColormap, Colormap))
+                and isinstance(colormap[1], VispyColormap | Colormap)
             ):
                 name = colormap[0]
                 cmap = colormap[1]
@@ -852,13 +854,13 @@ def ensure_colormap(colormap: ValidColormapArg) -> Colormap:
 
         elif isinstance(colormap, dict):
             if 'colors' in colormap and not (
-                isinstance(colormap['colors'], (VispyColormap, Colormap))
+                isinstance(colormap['colors'], VispyColormap | Colormap)
             ):
                 cmap = Colormap(**colormap)
                 name = cmap.name
                 AVAILABLE_COLORMAPS[name] = cmap
             elif not all(
-                (isinstance(i, (VispyColormap, Colormap)))
+                (isinstance(i, VispyColormap | Colormap))
                 for i in colormap.values()
             ):
                 raise TypeError(
@@ -920,9 +922,9 @@ def ensure_colormap(colormap: ValidColormapArg) -> Colormap:
 
 def _colormap_from_colors(
     colors: ColorType,
-    name: Optional[str] = 'custom',
-    display_name: Optional[str] = None,
-) -> Optional[Colormap]:
+    name: str | None = 'custom',
+    display_name: str | None = None,
+) -> Colormap | None:
     try:
         color_array = transform_color(colors)
     except (ValueError, AttributeError, KeyError):
