@@ -34,27 +34,19 @@ To create a keymap that will block others, ``bind_key(..., ...)```.
 
 import contextlib
 import inspect
-import sys
 import time
 from collections import ChainMap
-from collections.abc import Mapping
-from types import MethodType
-from typing import Callable, Union
+from collections.abc import Callable, Mapping
+from types import EllipsisType, MethodType
+from typing import Union
 
 from app_model.types import KeyBinding, KeyCode, KeyMod
 from vispy.util import keys
 
 from napari.utils.translations import trans
 
-if sys.version_info >= (3, 10):
-    from types import EllipsisType
-else:
-    EllipsisType = type(Ellipsis)
-
 KeyBindingLike = Union[KeyBinding, str, int]
-Keymap = Mapping[
-    Union[KeyBinding, EllipsisType], Union[Callable, EllipsisType]
-]
+Keymap = Mapping[KeyBinding | EllipsisType, Callable | EllipsisType]
 
 # global user keymap; to be made public later in refactoring process
 USER_KEYMAP: Mapping[str, Callable] = {}
@@ -136,7 +128,7 @@ def coerce_keybinding(key_bind: KeyBindingLike) -> KeyBinding:
 
 def bind_key(
     keymap: Keymap,
-    key_bind: Union[KeyBindingLike, EllipsisType],
+    key_bind: KeyBindingLike | EllipsisType,
     func=_UNDEFINED,
     *,
     overwrite=False,
