@@ -1,4 +1,5 @@
 import csv
+import itertools
 import os
 import re
 import tempfile
@@ -27,7 +28,7 @@ IMAGEIO_EXTENSIONS = {x for f in formats for x in f.extensions}
 READER_EXTENSIONS = IMAGEIO_EXTENSIONS.union({'.zarr', '.lsm', '.npy'})
 
 
-def _alphanumeric_key(s: str) -> list[Union[str, int]]:
+def _alphanumeric_key(s: str) -> list[str | int]:
     """Convert string to list of strings and ints that gives intuitive sorting."""
     return [int(c) if c.isdigit() else c for c in re.split('([0-9]+)', s)]
 
@@ -158,7 +159,7 @@ PathOrStr = Union[str, Path]
 
 
 def magic_imread(
-    filenames: Union[PathOrStr, list[PathOrStr]], *, use_dask=None, stack=True
+    filenames: PathOrStr | list[PathOrStr], *, use_dask=None, stack=True
 ):
     """Dispatch the appropriate reader given some files.
 
@@ -185,7 +186,7 @@ def magic_imread(
     """
     _filenames: list[str] = (
         [str(x) for x in filenames]
-        if isinstance(filenames, (list, tuple))
+        if isinstance(filenames, list | tuple)
         else [str(filenames)]
     )
     if not _filenames:  # pragma: no cover
@@ -344,7 +345,7 @@ def _shapes_csv_to_layerdata(
 
     data = []
     shape_type = []
-    for ind_a, ind_b in zip(shape_boundaries[:-1], shape_boundaries[1:]):
+    for ind_a, ind_b in itertools.pairwise(shape_boundaries):
         data.append(raw_data[ind_a:ind_b])
         shape_type.append(table[ind_a, 1])
 
@@ -353,7 +354,7 @@ def _shapes_csv_to_layerdata(
 
 def _guess_layer_type_from_column_names(
     column_names: list[str],
-) -> Optional[str]:
+) -> str | None:
     """Guess layer type based on column names from a csv file.
 
     Parameters
@@ -377,8 +378,8 @@ def _guess_layer_type_from_column_names(
 
 
 def read_csv(
-    filename: str, require_type: Optional[str] = None
-) -> tuple[np.ndarray, list[str], Optional[str]]:
+    filename: str, require_type: str | None = None
+) -> tuple[np.ndarray, list[str], str | None]:
     """Return CSV data only if column names match format for ``require_type``.
 
     Reads only the first line of the CSV at first, then optionally raises an
@@ -446,7 +447,7 @@ csv_reader_functions = {
 
 
 def csv_to_layer_data(
-    path: str, require_type: Optional[str] = None
+    path: str, require_type: str | None = None
 ) -> Optional['FullLayerData']:
     """Return layer data from a CSV file if detected as a valid type.
 
@@ -488,7 +489,7 @@ def csv_to_layer_data(
     return None  # only reachable if it is a valid layer type without a reader
 
 
-def _csv_reader(path: Union[str, Sequence[str]]) -> list['LayerData']:
+def _csv_reader(path: str | Sequence[str]) -> list['LayerData']:
     if isinstance(path, str):
         layer_data = csv_to_layer_data(path, require_type=None)
         return [layer_data] if layer_data else []
@@ -504,7 +505,7 @@ def _magic_imreader(path: str) -> list['LayerData']:
 
 
 def napari_get_reader(
-    path: Union[str, list[str]],
+    path: str | list[str],
 ) -> Optional['ReaderFunction']:
     """Our internal fallback file reader at the end of the reader plugin chain.
 
